==> digikam_2.8.0.orig.tar.bz2: digikam-2.8.0/core/libs/database/imageinfolist.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2007-03-20
 * Description : Container for image info objects
 *
 * Copyright (C) 2007-2008 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef IMAGEINFOLIST_H
#define IMAGEINFOLIST_H

// Qt includes

#include <QList>

// Local includes

#include "imageinfo.h"
#include "digikam_export.h"
#include "config-digikam.h"

namespace Digikam
{

class ImageInfo;

class DIGIKAM_DATABASE_EXPORT ImageInfoList : public QList<ImageInfo>
{

public:

    ImageInfoList() {}
    ImageInfoList(const QList<qlonglong>& idList);
    ImageInfoList(const QList<ImageInfo>& list)
        : QList<ImageInfo>(list) {}

    QList<qlonglong> toImageIdList() const;

    void loadGroupImageIds() const;
    void loadTagIds() const;
    bool static namefileLessThan(const ImageInfo &d1, const ImageInfo &d2);
};

typedef ImageInfoList::iterator ImageInfoListIterator;

}  // namespace Digikam

Q_DECLARE_METATYPE(Digikam::ImageInfoList)

#endif // IMAGEINFOLIST_H

==> digikam-3.1.0.tar.bz2: digikam-3.1.0/core/libs/database/imageinfolist.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2007-03-20
 * Description : Container for image info objects
 *
 * Copyright (C) 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef IMAGEINFOLIST_H
#define IMAGEINFOLIST_H

// Qt includes

#include <QList>

// Local includes

#include "imageinfo.h"
#include "digikam_export.h"
#include "config-digikam.h"

namespace Digikam
{

class ImageInfo;

class DIGIKAM_DATABASE_EXPORT ImageInfoList : public QList<ImageInfo>
{

public:

    ImageInfoList()
    {
    }

    ImageInfoList(const QList<qlonglong>& idList);

    ImageInfoList(const QList<ImageInfo>& list)
        : QList<ImageInfo>(list)
    {
    }

    QList<qlonglong> toImageIdList() const;

    void loadGroupImageIds() const;
    void loadTagIds() const;

    bool static namefileLessThan(const ImageInfo &d1, const ImageInfo &d2);
};

typedef ImageInfoList::iterator ImageInfoListIterator;

}  // namespace Digikam

Q_DECLARE_METATYPE(Digikam::ImageInfoList)

#endif // IMAGEINFOLIST_H
